#!/usr/bin/env python
# encoding: utf-8
'''
bin.gus_get_cycle_time -- shortdesc

bin.gus_get_cycle_time is a description

It defines classes_and_methods

@author:     user_name

@copyright:  2015 organization_name. All rights reserved.

@license:    license

@contact:    user_email
@deffield    updated: Updated
'''

import sys
import os
import traceback

from optparse import OptionParser

from gus.BacklogClient import BacklogClient
from gus.DependencyClient import DependencyClient
from gus.stats.CycleTime import CycleTime

__all__ = []
__version__ = 0.1
__date__ = '2015-09-18'
__updated__ = '2015-09-18'


def main(argv=None):
    '''Command line options.'''

    program_name = os.path.basename(sys.argv[0])
    program_version = "v0.1"
    program_build_date = "%s" % __updated__

    program_version_string = '%%prog %s (%s)' % (program_version, program_build_date)
    #program_usage = '''usage: spam two eggs''' # optional - will be autogenerated by optparse
    program_longdesc = '''''' # optional - give further explanation about what the program does
    program_license = "Copyright 2015 user_name (organization_name)                                            \
                Licensed under the Apache License 2.0\nhttp://www.apache.org/licenses/LICENSE-2.0"

    if argv is None:
        argv = sys.argv[1:]
    try:
        # setup option parser
        parser = OptionParser(version=program_version_string, epilog=program_longdesc, description=program_license)

        # set defaults
        parser.set_defaults(outfile="./out.txt", infile="./in.txt")

        # process options
        (opts, args) = parser.parse_args(argv)

        # MAIN BODY #
        if len(args) == 0:
            raise Exception("You must specify a W#")
        
        gus = BacklogClient()
        dep = DependencyClient()
        work = gus.find_work(args[0])
        history = gus.get_work_record_status_history(work['Id'])
        stats = CycleTime(history)
        ct = stats.calculate_cycle_time()
        
        stats.real_start = dep.get_earliest_start(stats.get_work_start_time(), work['Id'])
        print("Story Cycle Time: {}, Total Cycle Time: {}".format(ct, stats.calculate_cycle_time()))

    except Exception as e:
        traceback.print_exc()
        
        indent = len(program_name) * " "
        sys.stderr.write(program_name + ": " + repr(e) + "\n")
        sys.stderr.write(indent + "  for help use --help")
        return 2


if __name__ == "__main__":
    sys.exit(main())